import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class NODE_OT_collapse_hide_unused_toggle(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_enum_definition_item_add(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_enum_definition_item_move(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_enum_definition_item_remove(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_tree_path_parent(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NodeAddOperator:
    def create_node(self, context, node_type): ...
    def deselect_nodes(self, context): ...
    def invoke(self, context, event): ...
    def poll(self, context): ...
    def store_mouse_cursor(self, context, event): ...

class NodeInterfaceOperator:
    def poll(self, context): ...

class NodeSetting(bpy_types.PropertyGroup):
    bl_rna: typing.Any
    id_data: typing.Any

    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_add_node(NodeAddOperator, bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def create_node(self, context, node_type): ...
    def description(self, _context, properties): ...
    def deselect_nodes(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def invoke(self, context, event): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def store_mouse_cursor(self, context, event): ...
    def type_recast(self): ...
    def values(self): ...

class NodeAddZoneOperator(NodeAddOperator):
    def create_node(self, context, node_type): ...
    def deselect_nodes(self, context): ...
    def execute(self, context): ...
    def invoke(self, context, event): ...
    def poll(self, context): ...
    def store_mouse_cursor(self, context, event): ...

class NODE_OT_interface_item_duplicate(NodeInterfaceOperator, bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_interface_item_new(NodeInterfaceOperator, bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def find_valid_socket_type(self, tree): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_interface_item_remove(NodeInterfaceOperator, bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_add_repeat_zone(NodeAddZoneOperator, NodeAddOperator, bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def create_node(self, context, node_type): ...
    def deselect_nodes(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def invoke(self, context, event): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def store_mouse_cursor(self, context, event): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_OT_add_simulation_zone(
    NodeAddZoneOperator, NodeAddOperator, bpy_types.Operator
):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def create_node(self, context, node_type): ...
    def deselect_nodes(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def invoke(self, context, event): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def store_mouse_cursor(self, context, event): ...
    def type_recast(self): ...
    def values(self): ...



import typing
import bmesh.types
import mathutils

GenericType = typing.TypeVar("GenericType")

def intersect_face_point(
    face: "bmesh.types.BMFace",
    point: typing.Union["mathutils.Vector", typing.Sequence[float]],
) -> bool:
    """Tests if the projection of a point is inside a face (using the face's normal).

    :param face: The face to test.
    :type face: 'bmesh.types.BMFace'
    :param point: The point to test.
    :type point: typing.Union['mathutils.Vector', typing.Sequence[float]]
    :rtype: bool
    :return: True when the projection of the point is in the face.
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

class ProgressReport:
    curr_step: typing.Any
    running: typing.Any
    start_time: typing.Any
    steps: typing.Any
    wm: typing.Any

    def enter_substeps(self, nbr, msg): ...
    def finalize(self): ...
    def initialize(self, wm): ...
    def leave_substeps(self, msg): ...
    def start(self): ...
    def step(self, msg, nbr): ...
    def update(self, msg): ...

class ProgressReportSubstep:
    final_msg: typing.Any
    level: typing.Any
    msg: typing.Any
    nbr: typing.Any
    progress: typing.Any

    def enter_substeps(self, nbr, msg): ...
    def leave_substeps(self, msg): ...
    def step(self, msg, nbr): ...



import typing

GenericType = typing.TypeVar("GenericType")

def is_registered(function: typing.Optional[int]) -> bool:
    """Check if this function is registered as a timer.

    :param function: Function to check.
    :type function: typing.Optional[int]
    :rtype: bool
    :return: True when this function is registered, otherwise False.
    """

    ...

def register(
    function: typing.Optional[typing.Callable],
    first_interval: typing.Optional[float] = 0,
    persistent: typing.Optional[bool] = False,
):
    """Add a new function that will be called after the specified amount of seconds.
    The function gets no arguments and is expected to return either None or a float.
    If None is returned, the timer will be unregistered.
    A returned number specifies the delay until the function is called again.
    functools.partial can be used to assign some parameters.

        :param function: The function that should called.
        :type function: typing.Optional[typing.Callable]
        :param first_interval: Seconds until the callback should be called the first time.
        :type first_interval: typing.Optional[float]
        :param persistent: Don't remove timer when a new file is loaded.
        :type persistent: typing.Optional[bool]
    """

    ...

def unregister(function: typing.Optional[typing.Any]):
    """Unregister timer.

    :param function: Function to unregister.
    :type function: typing.Optional[typing.Any]
    """

    ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class UnifiedPaintPanel:
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class VIEW3D_MT_tools_projectpaint_clone(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class BrushPanel(UnifiedPaintPanel):
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class BrushSelectPanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any

    def draw(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class ClonePanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def draw_header(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class ColorPalettePanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class DisplayPanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def draw_header(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class FalloffPanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class SmoothStrokePanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def draw_header(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class StrokePanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_ui_units_x: typing.Any

    def draw(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

class TextureMaskPanel(BrushPanel, UnifiedPaintPanel):
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def get_brush_mode(self, context): ...
    def paint_settings(self, context): ...
    def poll(self, context): ...
    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ): ...
    def prop_unified_color(self, parent, context, brush, prop_name, text): ...
    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ): ...

def brush_basic__draw_color_selector(context, layout, brush, gp_settings, props): ...
def brush_basic_gpencil_paint_settings(layout, context, brush, compact): ...
def brush_basic_gpencil_sculpt_settings(layout, _context, brush, compact): ...
def brush_basic_gpencil_vertex_settings(layout, _context, brush, compact): ...
def brush_basic_gpencil_weight_settings(layout, _context, brush, compact): ...
def brush_basic_texpaint_settings(layout, context, brush, compact): ...
def brush_mask_texture_settings(layout, brush): ...
def brush_settings(layout, context, brush, popover): ...
def brush_settings_advanced(layout, context, brush, popover): ...
def brush_shared_settings(layout, context, brush, popover): ...
def brush_texture_settings(layout, brush, sculpt): ...
def draw_color_settings(context, layout, brush, color_type): ...



import typing
import bpy.types
import mathutils

GenericType = typing.TypeVar("GenericType")

def location_3d_to_region_2d(
    region: "bpy.types.Region",
    rv3d: "bpy.types.RegionView3D",
    coord: "mathutils.Vector",
    *,
    default=None,
) -> "mathutils.Vector":
    """Return the region relative 2d location of a 3d position.

        :param region: region of the 3D viewport, typically bpy.context.region.
        :type region: 'bpy.types.Region'
        :param rv3d: 3D region data, typically bpy.context.space_data.region_3d.
        :type rv3d: 'bpy.types.RegionView3D'
        :param coord: 3d world-space location.
        :type coord: 'mathutils.Vector'
        :param default: Return this value if coord
    is behind the origin of a perspective view.
        :rtype: 'mathutils.Vector'
        :return: 2d location
    """

    ...

def region_2d_to_location_3d(
    region: "bpy.types.Region",
    rv3d: "bpy.types.RegionView3D",
    coord: "mathutils.Vector",
    depth_location: "mathutils.Vector",
) -> "mathutils.Vector":
    """Return a 3d location from the region relative 2d coords, aligned with
    depth_location.

        :param region: region of the 3D viewport, typically bpy.context.region.
        :type region: 'bpy.types.Region'
        :param rv3d: 3D region data, typically bpy.context.space_data.region_3d.
        :type rv3d: 'bpy.types.RegionView3D'
        :param coord: 2d coordinates relative to the region;
    (event.mouse_region_x, event.mouse_region_y) for example.
        :type coord: 'mathutils.Vector'
        :param depth_location: the returned vectors depth is aligned with this since
    there is no defined depth with a 2d region input.
        :type depth_location: 'mathutils.Vector'
        :rtype: 'mathutils.Vector'
        :return: normalized 3d vector.
    """

    ...

def region_2d_to_origin_3d(
    region: "bpy.types.Region",
    rv3d: "bpy.types.RegionView3D",
    coord: "mathutils.Vector",
    *,
    clamp: typing.Optional[float] = None,
) -> "mathutils.Vector":
    """Return the 3d view origin from the region relative 2d coords.

        :param region: region of the 3D viewport, typically bpy.context.region.
        :type region: 'bpy.types.Region'
        :param rv3d: 3D region data, typically bpy.context.space_data.region_3d.
        :type rv3d: 'bpy.types.RegionView3D'
        :param coord: 2d coordinates relative to the region;
    (event.mouse_region_x, event.mouse_region_y) for example.
        :type coord: 'mathutils.Vector'
        :param clamp: Clamp the maximum far-clip value used.
    (negative value will move the offset away from the view_location)
        :type clamp: typing.Optional[float]
        :rtype: 'mathutils.Vector'
        :return: The origin of the viewpoint in 3d space.
    """

    ...

def region_2d_to_vector_3d(
    region: "bpy.types.Region",
    rv3d: "bpy.types.RegionView3D",
    coord: "mathutils.Vector",
) -> "mathutils.Vector":
    """Return a direction vector from the viewport at the specific 2d region
    coordinate.

        :param region: region of the 3D viewport, typically bpy.context.region.
        :type region: 'bpy.types.Region'
        :param rv3d: 3D region data, typically bpy.context.space_data.region_3d.
        :type rv3d: 'bpy.types.RegionView3D'
        :param coord: 2d coordinates relative to the region:
    (event.mouse_region_x, event.mouse_region_y) for example.
        :type coord: 'mathutils.Vector'
        :rtype: 'mathutils.Vector'
        :return: normalized 3d vector.
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

class ImBuf:
    channels: int
    """ Number of bit-planes.

    :type: int
    """

    filepath: str
    """ filepath associated with this image.

    :type: str
    """

    planes: int
    """ Number of bits associated with this image.

    :type: int
    """

    ppm: typing.Any
    """ pixels per meter.

    :type: typing.Any
    """

    size: typing.Any
    """ size of the image in pixels.

    :type: typing.Any
    """

    def copy(self) -> "ImBuf":
        """

        :rtype: 'ImBuf'
        :return: A copy of the image.
        """
        ...

    def crop(self, min: typing.Any, max: typing.Any):
        """Crop the image.

        :param min: X, Y minimum.
        :type min: typing.Any
        :param max: X, Y maximum.
        :type max: typing.Any
        """
        ...

    def free(self):
        """Clear image data immediately (causing an error on re-use)."""
        ...

    def resize(self, size: typing.Any, method: str = "FAST"):
        """Resize the image.

        :param size: New size.
        :type size: typing.Any
        :param method: Method of resizing ('FAST', 'BILINEAR')
        :type method: str
        """
        ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def color_add(override_context=None, execution_context=None, undo=None):
    """Add new color to active palette

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def color_delete(override_context=None, execution_context=None, undo=None):
    """Remove active color from palette

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def color_move(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    type: typing.Optional[typing.Any] = "UP",
):
    """Move the active Color up/down in the list

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    """

    ...

def extract_from_image(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    threshold: typing.Optional[typing.Any] = 1,
):
    """Extract all colors used in Image and create a Palette

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param threshold: Threshold
    :type threshold: typing.Optional[typing.Any]
    """

    ...

def join(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    palette: typing.Union[str, typing.Any] = "",
):
    """Join Palette Swatches

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param palette: Palette, Name of the Palette
    :type palette: typing.Union[str, typing.Any]
    """

    ...

def new(override_context=None, execution_context=None, undo=None):
    """Add new palette

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def sort(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    type: typing.Optional[typing.Any] = "HSV",
):
    """Sort Palette Colors

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    """

    ...



import typing
import bmesh.types

GenericType = typing.TypeVar("GenericType")

def edge_rotate(edge: "bmesh.types.BMEdge", ccw: bool = False) -> "bmesh.types.BMEdge":
    """Rotate the edge and return the newly created edge.
    If rotating the edge fails, None will be returned.

        :param edge: The edge to rotate.
        :type edge: 'bmesh.types.BMEdge'
        :param ccw: When True the edge will be rotated counter clockwise.
        :type ccw: bool
        :rtype: 'bmesh.types.BMEdge'
        :return: The newly rotated edge.
    """

    ...

def edge_split(
    edge: "bmesh.types.BMEdge", vert: "bmesh.types.BMVert", fac: float
) -> typing.Tuple:
    """Split an edge, return the newly created data.

    :param edge: The edge to split.
    :type edge: 'bmesh.types.BMEdge'
    :param vert: One of the verts on the edge, defines the split direction.
    :type vert: 'bmesh.types.BMVert'
    :param fac: The point on the edge where the new vert will be created [0 - 1].
    :type fac: float
    :rtype: typing.Tuple
    :return: The newly created (edge, vert) pair.
    """

    ...

def face_flip(faces):
    """Flip the faces direction."""

    ...

def face_join(faces: "bmesh.types.BMFace", remove: bool = True) -> "bmesh.types.BMFace":
    """Joins a sequence of faces.

    :param faces: Sequence of faces.
    :type faces: 'bmesh.types.BMFace'
    :param remove: Remove the edges and vertices between the faces.
    :type remove: bool
    :rtype: 'bmesh.types.BMFace'
    :return: The newly created face or None on failure.
    """

    ...

def face_split(
    face: "bmesh.types.BMFace",
    vert_a: "bmesh.types.BMVert",
    vert_b: "bmesh.types.BMVert",
    coords: typing.List[float] = (),
    use_exist: bool = True,
    example: "bmesh.types.BMEdge" = None,
) -> typing.Tuple["bmesh.types.BMFace", "bmesh.types.BMLoop"]:
    """Face split with optional intermediate points.

    :param face: The face to cut.
    :type face: 'bmesh.types.BMFace'
    :param vert_a: First vertex to cut in the face (face must contain the vert).
    :type vert_a: 'bmesh.types.BMVert'
    :param vert_b: Second vertex to cut in the face (face must contain the vert).
    :type vert_b: 'bmesh.types.BMVert'
    :param coords: Optional argument to define points in between vert_a and vert_b.
    :type coords: typing.List[float]
    :param use_exist: .Use an existing edge if it exists (Only used when coords argument is empty or omitted)
    :type use_exist: bool
    :param example: Newly created edge will copy settings from this one.
    :type example: 'bmesh.types.BMEdge'
    :rtype: typing.Tuple['bmesh.types.BMFace', 'bmesh.types.BMLoop']
    :return: The newly created face or None on failure.
    """

    ...

def face_split_edgenet(
    face: "bmesh.types.BMFace", edgenet: "bmesh.types.BMEdge"
) -> typing.Tuple:
    """Splits a face into any number of regions defined by an edgenet.

    :param face: The face to split.
    :type face: 'bmesh.types.BMFace'
    :param edgenet: Sequence of edges.
    :type edgenet: 'bmesh.types.BMEdge'
    :rtype: typing.Tuple
    :return: The newly created faces.
    """

    ...

def face_vert_separate(
    face: "bmesh.types.BMFace", vert: "bmesh.types.BMVert"
) -> "bmesh.types.BMVert":
    """Rip a vertex in a face away and add a new vertex.

    :param face: The face to separate.
    :type face: 'bmesh.types.BMFace'
    :param vert: A vertex in the face to separate.
    :type vert: 'bmesh.types.BMVert'
    :rtype: 'bmesh.types.BMVert'
    :return: The newly created vertex or None on failure.
    """

    ...

def loop_separate(loop: "bmesh.types.BMLoop") -> "bmesh.types.BMVert":
    """Rip a vertex in a face away and add a new vertex.

    :param loop: The loop to separate.
    :type loop: 'bmesh.types.BMLoop'
    :rtype: 'bmesh.types.BMVert'
    :return: The newly created vertex or None on failure.
    """

    ...

def vert_collapse_edge(
    vert: "bmesh.types.BMVert", edge: "bmesh.types.BMEdge"
) -> "bmesh.types.BMEdge":
    """Collapse a vertex into an edge.

    :param vert: The vert that will be collapsed.
    :type vert: 'bmesh.types.BMVert'
    :param edge: The edge to collapse into.
    :type edge: 'bmesh.types.BMEdge'
    :rtype: 'bmesh.types.BMEdge'
    :return: The resulting edge from the collapse operation.
    """

    ...

def vert_collapse_faces(
    vert: "bmesh.types.BMVert", edge: "bmesh.types.BMEdge", fac: float, join_faces: bool
) -> "bmesh.types.BMEdge":
    """Collapses a vertex that has only two manifold edges onto a vertex it shares an edge with.

    :param vert: The vert that will be collapsed.
    :type vert: 'bmesh.types.BMVert'
    :param edge: The edge to collapse into.
    :type edge: 'bmesh.types.BMEdge'
    :param fac: The factor to use when merging customdata [0 - 1].
    :type fac: float
    :param join_faces: When true the faces around the vertex will be joined otherwise collapse the vertex by merging the 2 edges this vertex connects to into one.
    :type join_faces: bool
    :rtype: 'bmesh.types.BMEdge'
    :return: The resulting edge from the collapse operation.
    """

    ...

def vert_dissolve(vert: "bmesh.types.BMVert") -> bool:
    """Dissolve this vertex (will be removed).

    :param vert: The vert to be dissolved.
    :type vert: 'bmesh.types.BMVert'
    :rtype: bool
    :return: True when the vertex dissolve is successful.
    """

    ...

def vert_separate(
    vert: "bmesh.types.BMVert", edges: "bmesh.types.BMEdge"
) -> typing.Tuple["bmesh.types.BMVert"]:
    """Separate this vertex at every edge.

    :param vert: The vert to be separated.
    :type vert: 'bmesh.types.BMVert'
    :param edges: The edges to separated.
    :type edges: 'bmesh.types.BMEdge'
    :rtype: typing.Tuple['bmesh.types.BMVert']
    :return: The newly separated verts (including the vertex passed).
    """

    ...

def vert_splice(vert: "bmesh.types.BMVert", vert_target: "bmesh.types.BMVert"):
    """Splice vert into vert_target.

    :param vert: The vertex to be removed.
    :type vert: 'bmesh.types.BMVert'
    :param vert_target: The vertex to use.
    :type vert_target: 'bmesh.types.BMVert'
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

def indent(levels): ...
def keyconfig_export_as_data(wm, kc, filepath, all_keymaps): ...
def keyconfig_import_from_data(name, keyconfig_data, keyconfig_version): ...
def keyconfig_init_from_data(kc, keyconfig_data): ...
def keyconfig_merge(kc1, kc2): ...
def keymap_init_from_data(km, km_items, is_modal): ...
def kmi_args_as_data(kmi): ...
def repr_f32(f): ...
def round_float_32(f): ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def new(override_context=None, execution_context=None, undo=None):
    """Create a new world Data-Block

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def copy(override_context=None, execution_context=None, undo=None):
    """Copy the material settings and nodes

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def new(override_context=None, execution_context=None, undo=None):
    """Add a new material

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def paste(override_context=None, execution_context=None, undo=None):
    """Paste the material settings and nodes

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class NODE_MT_category_shader_color(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_converter(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_group(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_input(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_output(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_script(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_shader(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_texture(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_category_shader_vector(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class NODE_MT_shader_node_add_all(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

def cycles_shader_nodes_poll(context): ...
def eevee_shader_nodes_poll(context): ...
def line_style_shader_nodes_poll(context): ...
def object_cycles_shader_nodes_poll(context): ...
def object_eevee_shader_nodes_poll(context): ...
def object_not_eevee_shader_nodes_poll(context): ...
def object_shader_nodes_poll(context): ...
def world_shader_nodes_poll(context): ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def edge_pan(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    inside_padding: typing.Optional[typing.Any] = 1.0,
    outside_padding: typing.Optional[typing.Any] = 0.0,
    speed_ramp: typing.Optional[typing.Any] = 1.0,
    max_speed: typing.Optional[typing.Any] = 500.0,
    delay: typing.Optional[typing.Any] = 1.0,
    zoom_influence: typing.Optional[typing.Any] = 0.0,
):
    """Pan the view when the mouse is held at an edge

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param inside_padding: Inside Padding, Inside distance in UI units from the edge of the region within which to start panning
    :type inside_padding: typing.Optional[typing.Any]
    :param outside_padding: Outside Padding, Outside distance in UI units from the edge of the region at which to stop panning
    :type outside_padding: typing.Optional[typing.Any]
    :param speed_ramp: Speed Ramp, Width of the zone in UI units where speed increases with distance from the edge
    :type speed_ramp: typing.Optional[typing.Any]
    :param max_speed: Max Speed, Maximum speed in UI units per second
    :type max_speed: typing.Optional[typing.Any]
    :param delay: Delay, Delay in seconds before maximum speed is reached
    :type delay: typing.Optional[typing.Any]
    :param zoom_influence: Zoom Influence, Influence of the zoom factor on scroll speed
    :type zoom_influence: typing.Optional[typing.Any]
    """

    ...

def ndof(override_context=None, execution_context=None, undo=None):
    """Use a 3D mouse device to pan/zoom the view

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def pan(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    deltax: typing.Optional[typing.Any] = 0,
    deltay: typing.Optional[typing.Any] = 0,
):
    """Pan the view

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param deltax: Delta X
    :type deltax: typing.Optional[typing.Any]
    :param deltay: Delta Y
    :type deltay: typing.Optional[typing.Any]
    """

    ...

def reset(override_context=None, execution_context=None, undo=None):
    """Reset the view

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def scroll_down(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    deltax: typing.Optional[typing.Any] = 0,
    deltay: typing.Optional[typing.Any] = 0,
    page: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Scroll the view down

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param deltax: Delta X
    :type deltax: typing.Optional[typing.Any]
    :param deltay: Delta Y
    :type deltay: typing.Optional[typing.Any]
    :param page: Page, Scroll down one page
    :type page: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def scroll_left(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    deltax: typing.Optional[typing.Any] = 0,
    deltay: typing.Optional[typing.Any] = 0,
):
    """Scroll the view left

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param deltax: Delta X
    :type deltax: typing.Optional[typing.Any]
    :param deltay: Delta Y
    :type deltay: typing.Optional[typing.Any]
    """

    ...

def scroll_right(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    deltax: typing.Optional[typing.Any] = 0,
    deltay: typing.Optional[typing.Any] = 0,
):
    """Scroll the view right

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param deltax: Delta X
    :type deltax: typing.Optional[typing.Any]
    :param deltay: Delta Y
    :type deltay: typing.Optional[typing.Any]
    """

    ...

def scroll_up(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    deltax: typing.Optional[typing.Any] = 0,
    deltay: typing.Optional[typing.Any] = 0,
    page: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Scroll the view up

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param deltax: Delta X
    :type deltax: typing.Optional[typing.Any]
    :param deltay: Delta Y
    :type deltay: typing.Optional[typing.Any]
    :param page: Page, Scroll up one page
    :type page: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def scroller_activate(override_context=None, execution_context=None, undo=None):
    """Scroll view by mouse click and drag

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def smoothview(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    xmin: typing.Optional[typing.Any] = 0,
    xmax: typing.Optional[typing.Any] = 0,
    ymin: typing.Optional[typing.Any] = 0,
    ymax: typing.Optional[typing.Any] = 0,
    wait_for_input: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Undocumented, consider contributing.

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param xmin: X Min
    :type xmin: typing.Optional[typing.Any]
    :param xmax: X Max
    :type xmax: typing.Optional[typing.Any]
    :param ymin: Y Min
    :type ymin: typing.Optional[typing.Any]
    :param ymax: Y Max
    :type ymax: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def zoom(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    deltax: typing.Optional[typing.Any] = 0.0,
    deltay: typing.Optional[typing.Any] = 0.0,
    use_cursor_init: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Zoom in/out the view

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param deltax: Delta X
    :type deltax: typing.Optional[typing.Any]
    :param deltay: Delta Y
    :type deltay: typing.Optional[typing.Any]
    :param use_cursor_init: Use Mouse Position, Allow the initial mouse position to be used
    :type use_cursor_init: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def zoom_border(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    xmin: typing.Optional[typing.Any] = 0,
    xmax: typing.Optional[typing.Any] = 0,
    ymin: typing.Optional[typing.Any] = 0,
    ymax: typing.Optional[typing.Any] = 0,
    wait_for_input: typing.Optional[typing.Union[bool, typing.Any]] = True,
    zoom_out: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Zoom in the view to the nearest item contained in the border

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param xmin: X Min
    :type xmin: typing.Optional[typing.Any]
    :param xmax: X Max
    :type xmax: typing.Optional[typing.Any]
    :param ymin: Y Min
    :type ymin: typing.Optional[typing.Any]
    :param ymax: Y Max
    :type ymax: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Optional[typing.Union[bool, typing.Any]]
    :param zoom_out: Zoom Out
    :type zoom_out: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def zoom_in(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    zoomfacx: typing.Optional[typing.Any] = 0.0,
    zoomfacy: typing.Optional[typing.Any] = 0.0,
):
    """Zoom in the view

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param zoomfacx: Zoom Factor X
    :type zoomfacx: typing.Optional[typing.Any]
    :param zoomfacy: Zoom Factor Y
    :type zoomfacy: typing.Optional[typing.Any]
    """

    ...

def zoom_out(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    zoomfacx: typing.Optional[typing.Any] = 0.0,
    zoomfacy: typing.Optional[typing.Any] = 0.0,
):
    """Zoom out the view

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param zoomfacx: Zoom Factor X
    :type zoomfacx: typing.Optional[typing.Any]
    :param zoomfacy: Zoom Factor Y
    :type zoomfacy: typing.Optional[typing.Any]
    """

    ...
